==> haskell-language-c99-0.2.0-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-language-c99.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 language-c99
version:              0.2.0
visibility:           public
id:                   language-c99-0.2.0-9Bt25M1E0uV1rzIt32rIr9
key:                  language-c99-0.2.0-9Bt25M1E0uV1rzIt32rIr9
license:              MIT
maintainer:           Frank Dedden <dev@dedden.net>
author:               Frank Dedden
synopsis:
    An implementation of the C99 AST that strictly follows the
    standard.

description:
    This package contains an implementation of the C99 AST as described in
    <http://www.open-std.org/jtc1/sc22/wg14/www/docs/n1256.pdf>. Sticking closely
    to this standard assures us that the program we deal with is a valid C99
    program.

    Additionally the library comes with a pretty printer.

    The package does not come with handy wrapper and utility functions to write a
    C99 program, it just contains the bare AST. It is highly recommended to use
    the wrapper provided by '\''language-c99-simple'\'' and '\''language-c99-util'\'' for
    writing programs.

category:             Language
abi:                  c5ecbde4c524d42d14c033497e96d5f1
exposed:              True
exposed-modules:      Language.C99 Language.C99.AST Language.C99.Pretty
import-dirs:          /usr/lib/ghc-9.0.2/site-local/language-c99-0.2.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/language-c99-0.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-language-c99
hs-libraries:         HSlanguage-c99-0.2.0-9Bt25M1E0uV1rzIt32rIr9
depends:              base-4.15.1.0 pretty-1.1.3.6
haddock-interfaces:
    /usr/share/doc/haskell-language-c99/html/language-c99.haddock

haddock-html:         /usr/share/doc/haskell-language-c99/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-language-c99-0.2.0-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-language-c99.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 language-c99
version:              0.2.0
visibility:           public
id:                   language-c99-0.2.0-DdMaUcm9U227hCUvFeLVWh
key:                  language-c99-0.2.0-DdMaUcm9U227hCUvFeLVWh
license:              MIT
maintainer:           Frank Dedden <dev@dedden.net>
author:               Frank Dedden
synopsis:
    An implementation of the C99 AST that strictly follows the
    standard.

description:
    This package contains an implementation of the C99 AST as described in
    <http://www.open-std.org/jtc1/sc22/wg14/www/docs/n1256.pdf>. Sticking closely
    to this standard assures us that the program we deal with is a valid C99
    program.

    Additionally the library comes with a pretty printer.

    The package does not come with handy wrapper and utility functions to write a
    C99 program, it just contains the bare AST. It is highly recommended to use
    the wrapper provided by '\''language-c99-simple'\'' and '\''language-c99-util'\'' for
    writing programs.

category:             Language
abi:                  aaf643a5d61cb3d5b803d6d3380dc845
exposed:              True
exposed-modules:      Language.C99 Language.C99.AST Language.C99.Pretty
import-dirs:          /usr/lib/ghc-9.2.8/site-local/language-c99-0.2.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/language-c99-0.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-language-c99
hs-libraries:         HSlanguage-c99-0.2.0-DdMaUcm9U227hCUvFeLVWh
depends:              base-4.16.4.0 pretty-1.1.3.6
haddock-interfaces:
    /usr/share/doc/haskell-language-c99/html/language-c99.haddock

haddock-html:         /usr/share/doc/haskell-language-c99/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
